Struct SecretKeyShare

pub struct SecretKeyShare(/* private fields */);
A secret key share.

Serde integration

SecretKeyShare implements Deserialize but not Serialize to avoid accidental serialization in insecure contexts. To enable both use the ::serde_impl::SerdeSecret wrapper which implements both Deserialize and Serialize.

Implementations

Source

impl SecretKeyShare

pub fn from_mut(fr: &mut Fr) -> Self

Creates a new SecretKeyShare from a mutable reference to a field element. This constructor takes a reference to avoid any unnecessary stack copying/moving of secrets field elements. The field element will be copied bytewise onto the heap, the resulting Box is stored in the SecretKey which is then wrapped in a SecretKeyShare.

WARNING this constructor will overwrite the pointed to Fr element with zeros once it has been copied into a new SecretKeyShare.

pub fn public_key_share(&self) -> PublicKeyShare

Returns the matching public key share.

pub fn sign_g2<H: Into<G2Affine>>(&self, hash: H) -> SignatureShare

Signs the given element of G2.

pub fn sign<M: AsRef<[u8]>>(&self, msg: M) -> SignatureShare

Signs the given message.

pub fn decrypt_share(&self, ct: &Ciphertext) -> Option<DecryptionShare>

Returns a decryption share, or None, if the ciphertext isn’t valid.

pub fn decrypt_share_no_verify(&self, ct: &Ciphertext) -> DecryptionShare

Returns a decryption share, without validating the ciphertext.

pub fn reveal(&self) -> String

Generates a non-redacted debug string. This method differs from the Debug implementation in that it does leak the secret prime field element.